/*Include headers */

#include "project.h"
#include <stdbool.h>
#include "stdio.h"
#include <stdlib.h>

/* For GCC compiler revise _write() function for DEBUG_BLE functionality */
int _write(int file, char *ptr, int len)
{
    int i;
    file = file;
    for (i = 0; i < len; i++)
    {
        UART_UartPutChar(*ptr++);
    }
    return len;
}

/* Macro definitions */
#define TRUE                        (1u)
#define FALSE                       (0u)

#define ENABLE                      TRUE
#define DISABLE                     FALSE

#define DEBUG_BLE_ENABLE            DISABLE

#if DEBUG_BLE_ENABLE
#define DEBUG_BLE       printf
#else
#define DEBUG_BLE(...)
#endif

#define DEFAULT_MTU_SIZE            ( 23u)
    
#define GATT_MTU                    (495u)
#define NOTIFICATION_PKT_SIZE       (GATT_MTU - 3)
  
/* The configurable GAP parameters */
#define TARGET_BDADDR               {{0xFF, 0xBB, 0xAA, 0x50, 0xA0, 0x00}, 0}

/* BT Address Size */
#define CY_BLE_BD_ADDR_SIZE         (0x06u)

/* The configurable GATT parameters */
#define CY_BLE_CCCD_LEN             (0x02u) 

/* Variable declaration */

uint8 buffer[1500]={0};
uint8 count = 1;

// tuner requests for write
uint8 tunerWrite=FALSE;

uint8 buffer_write[50]={0};
uint16 index_pos = FALSE;
uint16 offset_address= FALSE;
uint8 numOfBytes = FALSE;
uint8 notify = FALSE;


/* Variables to keep track of BLE connection handle */

CYBLE_API_RESULT_T	apiResult; /* Variable to store BLE api returns */
CYBLE_GAP_BD_ADDR_T local_addr; // variable to store the address to CONNECT
CYBLE_GAP_BD_ADDR_T remote_addr = TARGET_BDADDR;

/* GAP Related Information */
bool    isConnected = false;
uint8   bdHandle;
bool    targetAddrFound = false;

/* CCD value to enable notification*/
uint8   desc_val[CY_BLE_CCCD_LEN] = {0};

CYBLE_CONN_HANDLE_T conn_handle;

CYBLE_GATTC_HANDLE_VALUE_NTF_PARAM_T *Notification;

CYBLE_GATTC_WRITE_REQ_T req, writerequest;

/*******************************************************************************
 * Function Name: StackEventHandler()
 ********************************************************************************
 *
 * Summary:
 *   This is an event callback function to receive events from the BLE Component.
 *
 *  event - the event code
 *  *eventParam - the event parameters
 *
 * Return:
 *   None
 *
 *******************************************************************************/

void StackEventHandler(uint32 eventCode, void * eventParam)
{     
	CYBLE_GAPC_ADV_REPORT_T *advReport;   	      
    uint8 bdAddrIndex;
    uint8_t scanState = CyBle_GetState();
    
    switch(eventCode)
    {
        case CYBLE_EVT_STACK_ON:
        
            /* Stack initialized; ready for scan */
            DEBUG_BLE("\n STACK ON \n");
            CyBle_GapcStartScan(CYBLE_SCANNING_FAST); 
            break;

            
        case CYBLE_EVT_GAPC_SCAN_PROGRESS_RESULT:
           
            advReport = (CYBLE_GAPC_ADV_REPORT_T *) eventParam;
                
            /* Process only for Advertisement packets, not on scan response packets */
            if(advReport->eventType != CYBLE_GAPC_SCAN_RSP)
            {
                /* Set address 'found' status temporarily */
                targetAddrFound = true;
                
                for(bdAddrIndex = 0; bdAddrIndex < CY_BLE_BD_ADDR_SIZE; bdAddrIndex++)
                {
                    /* Set targetAddrFound status to false if BD address bytes don't match */
                    if (advReport->peerBdAddr[bdAddrIndex] != remote_addr.bdAddr[bdAddrIndex]) 
                    {
                        targetAddrFound = false;
                    }
                }

                if (targetAddrFound == true)
                {
                    DEBUG_BLE("Found target device with address: ");
                    DEBUG_BLE("%02X:%02X:%02X:%02X:%02X:%02X\r\n\n",advReport->peerBdAddr[5],\
                    advReport->peerBdAddr[4], advReport->peerBdAddr[3], advReport->peerBdAddr[2],\
                    advReport->peerBdAddr[1], advReport->peerBdAddr[0]);
                    CyBle_GapcStopScan();
                }
            }			
            break;
        
        
        case CYBLE_EVT_GAPC_SCAN_START_STOP:
            
            DEBUG_BLE("CY_BLE_EVT_GAPC_SCAN_START_STOP, scanstate = ");
          
            if(scanState == CYBLE_STATE_SCANNING)
                DEBUG_BLE("CY_BLE_SCAN_STATE_SCANNING\r\n");
                
            else
                {
                    if(targetAddrFound == true)
                    {
                        /* Scan stopped manually; do not restart scan */
                        targetAddrFound = false;
                        DEBUG_BLE("Scan stopped as device was found. Initiating Connection...\r\n\n");
                        apiResult = CyBle_GapcConnectDevice(&remote_addr);

                        if(apiResult != CYBLE_ERROR_OK)
                        {
                            DEBUG_BLE("Failed to initiate connection \r\n");
                        }
                        else
                        {
                            DEBUG_BLE("Initiated GAP connection..\r\n");
                        }
                    }
                    else
                    {
                        /* Scanning timed out; Restart scan */
                        DEBUG_BLE("Timed Out. Restarting scan...\r\n\n");
                        CyBle_GapcStartScan(CYBLE_SCANNING_FAST); 
                    }
                }
            break;
                        
        case CYBLE_EVT_GAP_DEVICE_CONNECTED:
                
                    
            DEBUG_BLE("\n\rConnected. "); 
            Connect_LED_Write(TRUE);
                                   
            /* Initiate an MTU exchange request */
            
            apiResult = CyBle_GattcExchangeMtuReq(cyBle_connHandle,GATT_MTU);
           
            if(apiResult != CYBLE_ERROR_OK)
            {
                DEBUG_BLE("Cy_BLE_GATTC_ExchangeMtuReq API Error: %xd \r\n", apiResult);
            }
            
            else
            {
                DEBUG_BLE("\n\rExchnage MTU request successful");
            }
                            
            break;
                
        case CYBLE_EVT_GATTC_XCHNG_MTU_RSP:
           
            /* Enable notifications on the characteristic to get data from the Server */
                         
            desc_val[0] = CYBLE_CCCD_NOTIFICATION;
            req.attrHandle =0x0014u;
            req.value.val = desc_val;
            req.value.len = 2;
    
            apiResult = CyBle_GattcWriteCharacteristicDescriptors(cyBle_connHandle, &req);
            if(apiResult != CYBLE_ERROR_OK)
            {
                DEBUG_BLE("Failed to enable notification");
                
            }
            
            else
            {
               DEBUG_BLE("Enabling notification");
            }
           
            break;
                       
        case CYBLE_EVT_GATT_DISCONNECT_IND:
            
            Connect_LED_Write(FALSE);
            /* Device disconnected; restart scan */
            DEBUG_BLE("\n Disconnected\n");
            
            CyBle_GapcStartScan(CYBLE_SCANNING_FAST);  
            
            break;
                 
        case CYBLE_EVT_GATTC_HANDLE_VALUE_NTF:
            
            Notification = (CYBLE_GATTC_HANDLE_VALUE_NTF_PARAM_T *)eventParam;
            
            if(Notification->handleValPair.attrHandle ==0x0012u )
            {   
               // DEBUG_BLE("\r\n Notofication arrived");
                if(Notification->handleValPair.value.len == 1u)
                {
                    count = *(Notification->handleValPair.value.val); 
                    
                     /* Set up communication and initialize data buffer 
                        to CapSense data structure to transfer data structure 
                        to BLE server 
                     */
                    EZI2C_EzI2CSetBuffer1(count*NOTIFICATION_PKT_SIZE, count*NOTIFICATION_PKT_SIZE, buffer);
                }
                
                else
                {
                    notify = TRUE;  
                }
            }
 
            break;        
                    
        default:
            break;
    }
}

int main(void)
{    
    CyGlobalIntEnable; /* Enable global interrupts. */
  
    /* Start EZI2C Component */
    EZI2C_Start(); 
       
    UART_Start();
    
    /* Start BLE operation */	
    apiResult = CyBle_Start(StackEventHandler);
    
    UART_UartPutString("========= BLE CLIENT =========\n\n\r");
    if(apiResult == CYBLE_ERROR_OK )
    {
        DEBUG_BLE("\r\nBLE start OK");
    }
    else
    {
        DEBUG_BLE("\r\nBLE failed");
    }
        
    uint8 i=0, j=0;
    
    
    for(;;)      
    {     
       
        if(EZI2C_EzI2CGetActivity() == EZI2C_EZI2C_STATUS_WRITE1)
        {
            EZI2C_DisableInt();
         
            offset_address = EZI2C_offsetBuf1;
            index_pos = EZI2C_indexBuf1; 
                           
            EZI2C_EnableInt();
            
            tunerWrite = TRUE;
            numOfBytes = index_pos - offset_address;
                
            for(i=0; i<numOfBytes; i++)
            {
               buffer_write[i+3] = buffer[offset_address+i]; 
            }
            
            DEBUG_BLE("\n\rOffset %d",offset_address);
            DEBUG_BLE("\n\rnumofbytes %d",numOfBytes);
            DEBUG_BLE("\n\r");
            for(int k= 0;k < numOfBytes ;k++)
            {
                printf("\n\rData : %d",buffer_write[k+3]);
            }
         
            buffer_write[2] = numOfBytes;
            buffer_write[0] = offset_address & 0x00FF;
            buffer_write[1] = (offset_address & 0xFF00)>>8;           
        }
                       
        if(notify)
        {
            EZI2C_DisableInt();
           
            memcpy(buffer+j*NOTIFICATION_PKT_SIZE,
                   Notification->handleValPair.value.val, NOTIFICATION_PKT_SIZE);                    
          
            notify = FALSE;
            
            CyBle_ProcessEvents();
            EZI2C_EnableInt();
        }
        
        if (tunerWrite)   
        {   
             CyBle_ProcessEvents(); 
           
            writerequest.attrHandle = 0x0016u;
            writerequest.value.val = buffer_write;           
            writerequest.value.len = numOfBytes + 3; 
          
            if(CyBle_GattGetBusyStatus()== CYBLE_STACK_STATE_FREE)
            {
                apiResult = CyBle_GattcWriteWithoutResponse(cyBle_connHandle,\
                                                            &writerequest);
                DEBUG_BLE("\n \r Tuner Write without Response");
                
                if(apiResult == CYBLE_ERROR_OK)
                    tunerWrite = FALSE;   
                else
                    DEBUG_BLE("\n GATTWRITE APIRESULT : %d \n",apiResult);
            }
        }

        CyBle_ProcessEvents();    
    }
}

/* [] END OF FILE */
