/*******************************************************************************
 * File Name: BLE_tuning.c
 *
 * Version: 1.00
 *
 * Description:
 *  This file contains BLE related functions.
 * 
 ********************************************************************************
 * Copyright 2019, Cypress Semiconductor Corporation.  All rights reserved.
 * You may use this file only in accordance with the license, terms, conditions,
 * disclaimers, and limitations in the end user license agreement accompanying
 * the software package with which this file was provided.
 *******************************************************************************/

#include "BLETuning.h"
#include "CapSenseMyTuner.h"
#include "stdbool.h"
#include "project.h"
#include "debug.h"




#define TRUE                        (1u)
#define FALSE                       (0u)

#define ENABLE                      TRUE
#define DISABLE                     FALSE


/*******************************************************************************
 * Macro definition
 *******************************************************************************/

#define MAX_MTU_SIZE                		(495u)
#define DEFAULT_MTU_SIZE            		(23u)
#define NOTIFICATION_PKT_SIZE       		(MAX_MTU_SIZE - 3u)

#define SUCCESS                     		(0u)
#define TARGET_BDADDR       				{{0xFF, 0xBB, 0xAA, 0x50, 0xA0, 0x00}, 0}
//#define CUSTOM_SERV0_CHAR0_DESC0_HANDLE     cy_ble_customConfig.customs[0]\
		//.customServInfo[0].customServCharDesc[0]
//#define CUSTOM_SERV0_CHAR0_HANDLE           cy_ble_customConfig.customs[0]\
		//.customServInfo[0].customServCharHandle


/*******************************************************************************
 * Variables to keep track of BLE connection handle
 *******************************************************************************/

bool charNotificationEnabled = false;
uint16 negotiatedMtu = DEFAULT_MTU_SIZE;

CYBLE_GAP_BD_ADDR_T    local_addr = TARGET_BDADDR;
CYBLE_CONN_HANDLE_T appConnHandle;
CYBLE_GATTS_HANDLE_VALUE_NTF_T notificationPacket;


/***************************************************************************
 * Global variables
 ***************************************************************************/

uint32 size = 0;
uint8 count = 1;
uint16 len = 0;
uint8 dataWritten = 0;
uint8 buffer_write[50] = {0};

/***************************************
 * Function Prototypes
 **************************************/

void Ble_Init(void);
void StackEventHandler(uint32 event, void* eventParam);
void CapSense_Init(void);

/*******************************************************************************
 * Function Name: CapSense_BleTuning_Init()
 ********************************************************************************
 *
 * Summary:
 *   This function initializes the BLE and UART components for use in the code
 *   code example.
 *
 * Parameters:
 *  None
 *
 * Return:
 *   None
 *
 *******************************************************************************/

void CapSense_BleTuning_Init(void)
{
	/* Enable interrupts */
	CyGlobalIntEnable; 

	/* Start the UART debug port */
	//UART_DEBUG_START();
    UART_Start();
	
    /* \x1b[2J\x1b[;H - ANSI ESC sequence for clear screen */
	DEBUG_PRINTF("\x1b[2J\x1b[;H");

	DEBUG_PRINTF("*****************CE PSoC 4 BLE server with CapSense sensors *******"\
			"**********\r\n");
	DEBUG_PRINTF("Role : BLE Server)\r\n");

	DEBUG_PRINTF("*****************************************************************"\
			"*****************\r\n\n");

	/* Initialize CapSense */
	CapSense_Init();

	/* Initialize BLE */
	Ble_Init();

}


/*******************************************************************************
 * Function Name: CapSense_Init()
 ********************************************************************************
 *
 * Summary:
 *   This function initializes BLE.
 *
 * Return:
 *   None
 *
 *******************************************************************************/
void CapSense_Init(void)
{
	/* Start CapSense Component */
	CapSense_Start();

	size = sizeof(CapSense_dsRam);

	while(1)
	{
		if(size > NOTIFICATION_PKT_SIZE)
		{
			size = size - NOTIFICATION_PKT_SIZE;
			count ++;
		}
		else
			break;
	}

	/* Start the initial CapSense scan */
	CapSense_ScanAllWidgets();  
}

/*******************************************************************************
 * Function Name: Ble_Init()
 ********************************************************************************
 *
 * Summary:
 *   This function initializes BLE.
 *
 * Return:
 *   None
 *
 *******************************************************************************/
void Ble_Init(void)
{
    CYBLE_API_RESULT_T apiResult;
    
	apiResult =CyBle_Start(StackEventHandler);
    
    if(apiResult == CYBLE_ERROR_OK )
    {
        DEBUG_PRINTF("\n\rBLE start OK");
    }
    else
    {
        DEBUG_PRINTF("\n\rBLE failed");
    }

}

/*******************************************************************************
 * Function Name: StackEventHandler()
 ********************************************************************************
 *
 * Summary:
 *   This is an event callback function to receive events from the BLE Component.
 *
 *  event - the event code
 *  *eventParam - the event parameters
 *
 * Return:
 *   None
 *
 *******************************************************************************/
void StackEventHandler(uint32 eventCode, void* eventParam)
{
	CYBLE_API_RESULT_T apiResult;
    
	switch(eventCode)
	{
	    /* There are some events generated by the BLE component
	    *  that are not required for this code example. */

	    /**********************************************************
	     *                       General Events
	    ***********************************************************/

	    /* This event is received when the BLE component is Started */
	    /* Stack initialized; ready for advertisement */
        case CYBLE_EVT_STACK_ON:
        {
            DEBUG_PRINTF("\nSTACK ON\n");
            apiResult = CyBle_SetDeviceAddress ((CYBLE_GAP_BD_ADDR_T *)&local_addr); 
            if(apiResult == CYBLE_ERROR_OK)
		    {
			    DEBUG_PRINTF("Cy_BLE_GAP_SetBdAddress API Error: %d \r\n",
					apiResult);
		    }
            CyBle_GappStartAdvertisement(CYBLE_ADVERTISING_FAST);
            break;
        }

	    /* This event is received when there is a timeout. */
    	case CYBLE_EVT_TIMEOUT:
        {
            DEBUG_PRINTF("\r\n");
            /* Possible timeout event parameter values:
            * CYBLE_GAP_ADV_MODE_TO -> GAP limited discoverable mode timeout;
            * CYBLE_GAP_AUTH_TO -> GAP pairing process timeout.
            */
            if(CYBLE_GAP_ADV_MODE_TO == *(uint8 *) eventParam)
            {
                DEBUG_PRINTF("Advertisement timeout occurred. Advertisement will be disabled.\r\n");
            }
            else
            {
                DEBUG_PRINTF("Timeout occurred.\r\n");
            }
        
            break;
        }

	    /* This event indicates that some internal HW error has occurred. */
    	case CYBLE_EVT_HARDWARE_ERROR:
        {
            DEBUG_PRINTF("\r\n");
            DEBUG_PRINTF("Hardware Error\r\n");
            break;
        }
            
        case CYBLE_EVT_HCI_STATUS:
        {
            DEBUG_PRINTF("\r\n");
            DEBUG_PRINTF("HCI Error. Error code is %x.\r\n", *(uint8 *) eventParam);
            break;
        }
        
        /*  This event will be triggered by host stack if BLE stack is busy or
	    *  not busy. Parameter corresponding to this event will be the state
	    *  of BLE stack.
	    *  BLE stack busy = CY_BLE_STACK_STATE_BUSY,
	    *  BLE stack not busy = CY_BLE_STACK_STATE_FREE
	    */
        
        case CYBLE_EVT_STACK_BUSY_STATUS:
        {
            DEBUG_PRINTF("CYBLE_EVT_STACK_BUSY_STATUS: %x \r\n",*(uint8 *)eventParam);
            break;
        }
        
        /**********************************************************
	    *                       GAP Events
	     **********************************************************/
        
        case CYBLE_EVT_GAPP_ADVERTISEMENT_START_STOP:
        {
            DEBUG_PRINTF("\nADV START STOP\n");
            if(CyBle_GetState() == CYBLE_STATE_DISCONNECTED)
            {
                CyBle_GappStartAdvertisement(CYBLE_ADVERTISING_FAST);
                DEBUG_PRINTF(" <Restart ADV> \r\n");
			    DEBUG_PRINTF("Advertising...\r\n\n");
                charNotificationEnabled = false;
            }
            break;
        }
        
        /* This event is generated at the GAP Peripheral end after connection
           is completed with peer Central device. */
        case CYBLE_EVT_GAP_DEVICE_CONNECTED:
        {
            DEBUG_PRINTF("\n Connected. ");
            ConnectLED_Write(0);  
            charNotificationEnabled = false;
            break;
        }
        
        /* This event is generated when disconnected from remote device or
           failed to establish connection. */
        
        case CYBLE_EVT_GAP_DEVICE_DISCONNECTED:
        {
            if(CyBle_GetState() == CYBLE_STATE_DISCONNECTED)
            {
                ConnectLED_Write(1);  
               DEBUG_PRINTF("\r\n Disconnected");
              
                CyBle_GappStartAdvertisement(CYBLE_ADVERTISING_FAST);
                DEBUG_PRINTF(" <Restart ADV> \r\n");
			    DEBUG_PRINTF("Advertising...\r\n\n");
                charNotificationEnabled = false;
            }
            break;
        }
        
        /* This event is generated at the GAP Central and the peripheral end
           after connection parameter update is requested from the host to
           the controller. */
        
        case CYBLE_EVT_GAP_CONNECTION_UPDATE_COMPLETE:
	    {
    		DEBUG_PRINTF("CY_BLE_EVT_GAP_CONNECTION_UPDATE_COMPLETE \r\n");
    		break;
	    }

	    /**********************************************************
	    *                       GATT Events
	    ***********************************************************/

	    /* This event is generated at the GAP Peripheral end after connection
           is completed with peer Central device. */
    	case CYBLE_EVT_GATT_CONNECT_IND:
    	{
    		appConnHandle = *(CYBLE_CONN_HANDLE_T*) eventParam;
    		DEBUG_PRINTF("CY_BLE_EVT_GATT_CONNECT_IND: %x, %x \r\n",
    				appConnHandle.attId,
    				appConnHandle.bdHandle);

    		break;
    	}

	
	    /* This event is generated at the GAP Peripheral end after disconnection. */
        case CYBLE_EVT_GATT_DISCONNECT_IND:
        {
    	    DEBUG_PRINTF("CY_BLE_EVT_GATT_DISCONNECT_IND \r\n");
    		if(appConnHandle.bdHandle == (*(CYBLE_CONN_HANDLE_T*)eventParam).bdHandle)
    		{
    			DEBUG_PRINTF("Disconnected. \r\n\n");
    			appConnHandle.bdHandle = 0xFF;
    			appConnHandle.attId    = 0xFF;
    		}
    	    break;
        }

	    /* This event is triggered when 'GATT MTU Exchange Request'
           received from GATT client device. */
        
        /* GATT MTU exchange request - Update the negotiated MTU value */
        case CYBLE_EVT_GATTS_XCNHG_MTU_REQ:
        {
            CyBle_GattsExchangeMtuRsp(cyBle_connHandle,512);
            DEBUG_PRINTF("MTU EXCHANGE REQ: %d  \n",((CYBLE_GATT_XCHG_MTU_PARAM_T *)eventParam)->mtu );
           
            break;
        }
        
        /* Check if the Client Characteristic Configuration Descriptor is written to. 
           Notification is enabled or disabled accordingly.
         */
        case CYBLE_EVT_GATTS_WRITE_REQ:
        {
            CYBLE_GATTS_WRITE_REQ_PARAM_T *writeParam;
            DEBUG_PRINTF("CY_BLE_EVT_GATTS_WRITE_REQ \r\n");
            writeParam = (CYBLE_GATTS_WRITE_REQ_PARAM_T *)eventParam;
            
            if(writeParam->handleValPair.attrHandle == 
               CYBLE_CAPSENSE_DS_CUSTOM_CHARACTERISTIC_CLIENT_CHARACTERISTIC_CONFIGURATION_DESC_HANDLE)
            {
                CyBle_GattsWriteRsp(writeParam->connHandle);
                DEBUG_PRINTF("GATT write response sent \r\n");
                charNotificationEnabled = writeParam->handleValPair.value.val[0];
                DEBUG_PRINTF("\n Notification is enabled\n");
                notificationPacket.attrHandle = CYBLE_CAPSENSE_DS_CUSTOM_CHARACTERISTIC_CHAR_HANDLE;
                notificationPacket.value.len = 1;
                notificationPacket.value.val = &count;
                
                apiResult = CyBle_GattsNotification(appConnHandle, &notificationPacket);
                if(apiResult == CYBLE_ERROR_OK)
    			{
    				DEBUG_PRINTF("\nNotification sent");
                    DEBUG_PRINTF("\r\n Count: %d", count);
    			}
            }
            break;
        }

    	case CYBLE_EVT_GATTS_WRITE_CMD_REQ:
    	{
            DEBUG_PRINTF("\n\r CYBLE_EVT_GATTS_WRITE_CMD_REQ event occured");
            
            CYBLE_GATTS_WRITE_CMD_REQ_PARAM_T *write_cmd_param = \
                                                               (CYBLE_GATTS_WRITE_CMD_REQ_PARAM_T*)\
                                                                eventParam;
            DEBUG_PRINTF(
                   "write_cmd_param->handleValPair.attrHandle = %d, expected = %d (CUSTOM_BLE_IN_HANDLE)\r\n",\
    			    write_cmd_param->handleValPair.attrHandle, 0\
                  );
            if(write_cmd_param->handleValPair.attrHandle == CYBLE_CAPSENSE_DS_CUSTOM_CHARACTERISTIC_2_CHAR_HANDLE)
    	    {
                CyBle_GattsWriteRsp(write_cmd_param->connHandle);
                memcpy(buffer_write,write_cmd_param->handleValPair.value.val,write_cmd_param->handleValPair.value.len);
    		    dataWritten = 1;
                TunerReceive();
    	    }
            break;
        }

    	case CYBLE_EVT_GATTS_READ_CHAR_VAL_ACCESS_REQ:
    	{
    		DEBUG_PRINTF("CY_BLE_EVT_GATTS_READ_CHAR_VAL_ACCESS_REQ \r\n");
    		break;
    	}

    	/**********************************************************
    	 *                       Other Events
    	 ***********************************************************/
    	default:
    		DEBUG_PRINTF("OTHER event: %lx \r\n", (unsigned long) eventCode);
    		break;
    }
}


void TunerSend(void)
{
    CYBLE_API_RESULT_T apiResult;
    volatile uint32 i=0;
    
    /*Call atleast once during a scan interval*/ 
    CyBle_ProcessEvents();
    
    if(charNotificationEnabled == true)
    {
            if(CyBle_GattGetBusyStatus() == CYBLE_STACK_STATE_FREE)
            {
                notificationPacket.attrHandle = \
                              CYBLE_CAPSENSE_DS_CUSTOM_CHARACTERISTIC_CHAR_HANDLE;
                
                notificationPacket.value.val = (uint8_t *)&CapSense_dsRam ;
                
                notificationPacket.value.len = NOTIFICATION_PKT_SIZE;
                
                apiResult = CyBle_GattsNotification(cyBle_connHandle, &notificationPacket);
                if(apiResult == CYBLE_ERROR_OK)
    			{
    				DEBUG_PRINTF("\nNotification sent");
			       
    			}    
                else
                {
                    DEBUG_PRINTF("\n\r Notification failed %x",apiResult);
                }
              
            }
        }
        
    }


void TunerReceive(void)
{
	CapSense_TU_CMD_ENUM command;
	volatile CapSense_RAM_STRUCT *ptrDsRam;
    
	/* Cy_Ble_ProcessEvents() allows BLE stack to process pending events */
	CyBle_ProcessEvents();

	if(dataWritten==1)
	{
		uint16 i = 0x0000;
		i = i | buffer_write[0];
		i = i | (buffer_write[1]<<8);

		len=buffer_write[2];
        
		for (int j = 0; j< len; j++)
		{
			*(((uint8_t *)&CapSense_dsRam) + i) = buffer_write[j+3];
            i++;
		}

		ptrDsRam = &CapSense_dsRam;
		command = (CapSense_TU_CMD_ENUM)ptrDsRam->tunerCmd;

		if(command == CapSense_TU_CMD_RESTART_E)
			(void)CapSense_Start();

		dataWritten =0;
	}
}

/* [] END OF FILE */
